;; Generated package description from windresize.el  -*- no-byte-compile: t -*-
(define-package "windresize" "0.1" "Resize windows interactively" 'nil :commit "0693d5d864ac9fd033c868bdd887e66278e056e9" :url "https://elpa.gnu.org/packages/windresize.html" :authors '(("Bastien" . "bzgATalternDOTorg")) :maintainer '("Bastien" . "bzgATalternDOTorg") :keywords '("window"))
